##  Deleting Scheduled Changes
To delete a scheduled change, you need to delete the corresponding impact in the transformation item:
  1. Go to the Transformations tab of the fact sheet.
  2. On the relevant transformation item, click Show next to Custom impacts.
  3. Hover over the relevant custom impact and click the delete icon.


YesNo
Send
